package js_of_ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Source file intersectionObserver.ml

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
(* Js_of_ocaml library
 * http://www.ocsigen.org/js_of_ocaml/
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, with linking exception;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *)

class type intersectionObserverEntry = object
  method target : Dom.node Js.t Js.readonly_prop

  method boundingClientRect : Dom_html.clientRect Js.t Js.readonly_prop

  method rootBounds : Dom_html.clientRect Js.t Js.opt Js.readonly_prop

  method intersectionRect : Dom_html.clientRect Js.t Js.readonly_prop

  method intersectionRatio : Js.number_t Js.readonly_prop

  method isIntersecting : bool Js.t Js.readonly_prop

  method time : Js.number_t Js.readonly_prop
end

class type intersectionObserverOptions = object
  method root : Dom.node Js.t Js.writeonly_prop

  method rootMargin : Js.js_string Js.t Js.writeonly_prop

  method threshold : Js.number_t Js.js_array Js.t Js.writeonly_prop
end

class type intersectionObserver = object
  method root : Dom.node Js.t Js.opt Js.readonly_prop

  method rootMargin : Js.js_string Js.t Js.readonly_prop

  method thresholds : Js.number_t Js.js_array Js.t Js.readonly_prop

  method observe : #Dom.node Js.t -> unit Js.meth

  method unobserve : #Dom.node Js.t -> unit Js.meth

  method disconnect : unit Js.meth

  method takeRecords : intersectionObserverEntry Js.t Js.js_array Js.meth
end

let empty_intersection_observer_options () : intersectionObserverOptions Js.t =
  Js.Unsafe.obj [||]

let intersectionObserver_unsafe = Js.Unsafe.global##._IntersectionObserver

let is_supported () = Js.Optdef.test intersectionObserver_unsafe

let intersectionObserver :
    (   (   intersectionObserverEntry Js.t Js.js_array Js.t
         -> intersectionObserver Js.t
         -> unit)
        Js.callback
     -> intersectionObserverOptions Js.t
     -> intersectionObserver Js.t)
    Js.constr =
  intersectionObserver_unsafe